==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkConstrainedPointHandleRepresentation.java <==
// java wrapper for vtkConstrainedPointHandleRepresentation object
//

package vtk;
import vtk.*;

public class vtkConstrainedPointHandleRepresentation extends vtkHandleRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCursorShape_2(vtkPolyData id0);
  public void SetCursorShape(vtkPolyData id0)
    { SetCursorShape_2(id0); }

  private native long GetCursorShape_3();
  public vtkPolyData GetCursorShape() {
    long temp = GetCursorShape_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetActiveCursorShape_4(vtkPolyData id0);
  public void SetActiveCursorShape(vtkPolyData id0)
    { SetActiveCursorShape_4(id0); }

  private native long GetActiveCursorShape_5();
  public vtkPolyData GetActiveCursorShape() {
    long temp = GetActiveCursorShape_5();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetProjectionNormal_6(int id0);
  public void SetProjectionNormal(int id0)
    { SetProjectionNormal_6(id0); }

  private native int GetProjectionNormalMinValue_7();
  public int GetProjectionNormalMinValue()
    { return GetProjectionNormalMinValue_7(); }

  private native int GetProjectionNormalMaxValue_8();
  public int GetProjectionNormalMaxValue()
    { return GetProjectionNormalMaxValue_8(); }

  private native int GetProjectionNormal_9();
  public int GetProjectionNormal()
    { return GetProjectionNormal_9(); }

  private native void SetProjectionNormalToXAxis_10();
  public void SetProjectionNormalToXAxis()
    { SetProjectionNormalToXAxis_10(); }

  private native void SetProjectionNormalToYAxis_11();
  public void SetProjectionNormalToYAxis()
    { SetProjectionNormalToYAxis_11(); }

  private native void SetProjectionNormalToZAxis_12();
  public void SetProjectionNormalToZAxis()
    { SetProjectionNormalToZAxis_12(); }

  private native void SetProjectionNormalToOblique_13();
  public void SetProjectionNormalToOblique()
    { SetProjectionNormalToOblique_13(); }

  private native void SetObliquePlane_14(vtkPlane id0);
  public void SetObliquePlane(vtkPlane id0)
    { SetObliquePlane_14(id0); }

  private native long GetObliquePlane_15();
  public vtkPlane GetObliquePlane() {
    long temp = GetObliquePlane_15();

    if (temp == 0) return null;
    return (vtkPlane)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetProjectionPosition_16(double id0);
  public void SetProjectionPosition(double id0)
    { SetProjectionPosition_16(id0); }

  private native double GetProjectionPosition_17();
  public double GetProjectionPosition()
    { return GetProjectionPosition_17(); }

  private native void AddBoundingPlane_18(vtkPlane id0);
  public void AddBoundingPlane(vtkPlane id0)
    { AddBoundingPlane_18(id0); }

  private native void RemoveBoundingPlane_19(vtkPlane id0);
  public void RemoveBoundingPlane(vtkPlane id0)
    { RemoveBoundingPlane_19(id0); }

  private native void RemoveAllBoundingPlanes_20();
  public void RemoveAllBoundingPlanes()
    { RemoveAllBoundingPlanes_20(); }

  private native void SetBoundingPlanes_21(vtkPlaneCollection id0);
  public void SetBoundingPlanes(vtkPlaneCollection id0)
    { SetBoundingPlanes_21(id0); }

  private native long GetBoundingPlanes_22();
  public vtkPlaneCollection GetBoundingPlanes() {
    long temp = GetBoundingPlanes_22();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetBoundingPlanes_23(vtkPlanes id0);
  public void SetBoundingPlanes(vtkPlanes id0)
    { SetBoundingPlanes_23(id0); }

  private native int CheckConstraint_24(vtkRenderer id0,double id1[]);
  public int CheckConstraint(vtkRenderer id0,double id1[])
    { return CheckConstraint_24(id0,id1); }

  private native void SetPosition_25(double id0,double id1,double id2);
  public void SetPosition(double id0,double id1,double id2)
    { SetPosition_25(id0,id1,id2); }

  private native void SetPosition_26(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_26(id0); }

  private native void GetPosition_27(double id0[]);
  public void GetPosition(double id0[])
    { GetPosition_27(id0); }

  private native long GetProperty_28();
  public vtkProperty GetProperty() {
    long temp = GetProperty_28();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedProperty_29();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_29();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetActiveProperty_30();
  public vtkProperty GetActiveProperty() {
    long temp = GetActiveProperty_30();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetRenderer_31(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_31(id0); }

  private native void BuildRepresentation_32();
  public void BuildRepresentation()
    { BuildRepresentation_32(); }

  private native void StartWidgetInteraction_33(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_33(id0); }

  private native void WidgetInteraction_34(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_34(id0); }

  private native int ComputeInteractionState_35(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_35(id0,id1,id2); }

  private native void SetDisplayPosition_36(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_36(id0); }

  private native void GetActors_37(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_37(id0); }

  private native void ReleaseGraphicsResources_38(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_38(id0); }

  private native int RenderOverlay_39(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_39(id0); }

  private native int RenderOpaqueGeometry_40(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_40(id0); }

  private native int RenderTranslucentPolygonalGeometry_41(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_41(id0); }

  private native int HasTranslucentPolygonalGeometry_42();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_42(); }

  private native void ShallowCopy_43(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_43(id0); }

  private native void Highlight_44(int id0);
  public void Highlight(int id0)
    { Highlight_44(id0); }

  public vtkConstrainedPointHandleRepresentation() { super(); }

  public vtkConstrainedPointHandleRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkConstrainedPointHandleRepresentation.java <==
// java wrapper for vtkConstrainedPointHandleRepresentation object
//

package vtk;
import vtk.*;

public class vtkConstrainedPointHandleRepresentation extends vtkHandleRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCursorShape_2(vtkPolyData id0);
  public void SetCursorShape(vtkPolyData id0)
    { SetCursorShape_2(id0); }

  private native long GetCursorShape_3();
  public vtkPolyData GetCursorShape() {
    long temp = GetCursorShape_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetActiveCursorShape_4(vtkPolyData id0);
  public void SetActiveCursorShape(vtkPolyData id0)
    { SetActiveCursorShape_4(id0); }

  private native long GetActiveCursorShape_5();
  public vtkPolyData GetActiveCursorShape() {
    long temp = GetActiveCursorShape_5();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProjectionNormal_6(int id0);
  public void SetProjectionNormal(int id0)
    { SetProjectionNormal_6(id0); }

  private native int GetProjectionNormalMinValue_7();
  public int GetProjectionNormalMinValue()
    { return GetProjectionNormalMinValue_7(); }

  private native int GetProjectionNormalMaxValue_8();
  public int GetProjectionNormalMaxValue()
    { return GetProjectionNormalMaxValue_8(); }

  private native int GetProjectionNormal_9();
  public int GetProjectionNormal()
    { return GetProjectionNormal_9(); }

  private native void SetProjectionNormalToXAxis_10();
  public void SetProjectionNormalToXAxis()
    { SetProjectionNormalToXAxis_10(); }

  private native void SetProjectionNormalToYAxis_11();
  public void SetProjectionNormalToYAxis()
    { SetProjectionNormalToYAxis_11(); }

  private native void SetProjectionNormalToZAxis_12();
  public void SetProjectionNormalToZAxis()
    { SetProjectionNormalToZAxis_12(); }

  private native void SetProjectionNormalToOblique_13();
  public void SetProjectionNormalToOblique()
    { SetProjectionNormalToOblique_13(); }

  private native void SetObliquePlane_14(vtkPlane id0);
  public void SetObliquePlane(vtkPlane id0)
    { SetObliquePlane_14(id0); }

  private native long GetObliquePlane_15();
  public vtkPlane GetObliquePlane() {
    long temp = GetObliquePlane_15();

    if (temp == 0) return null;
    return (vtkPlane)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProjectionPosition_16(double id0);
  public void SetProjectionPosition(double id0)
    { SetProjectionPosition_16(id0); }

  private native double GetProjectionPosition_17();
  public double GetProjectionPosition()
    { return GetProjectionPosition_17(); }

  private native void AddBoundingPlane_18(vtkPlane id0);
  public void AddBoundingPlane(vtkPlane id0)
    { AddBoundingPlane_18(id0); }

  private native void RemoveBoundingPlane_19(vtkPlane id0);
  public void RemoveBoundingPlane(vtkPlane id0)
    { RemoveBoundingPlane_19(id0); }

  private native void RemoveAllBoundingPlanes_20();
  public void RemoveAllBoundingPlanes()
    { RemoveAllBoundingPlanes_20(); }

  private native void SetBoundingPlanes_21(vtkPlaneCollection id0);
  public void SetBoundingPlanes(vtkPlaneCollection id0)
    { SetBoundingPlanes_21(id0); }

  private native long GetBoundingPlanes_22();
  public vtkPlaneCollection GetBoundingPlanes() {
    long temp = GetBoundingPlanes_22();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBoundingPlanes_23(vtkPlanes id0);
  public void SetBoundingPlanes(vtkPlanes id0)
    { SetBoundingPlanes_23(id0); }

  private native int CheckConstraint_24(vtkRenderer id0,double id1[]);
  public int CheckConstraint(vtkRenderer id0,double id1[])
    { return CheckConstraint_24(id0,id1); }

  private native void SetPosition_25(double id0,double id1,double id2);
  public void SetPosition(double id0,double id1,double id2)
    { SetPosition_25(id0,id1,id2); }

  private native void SetPosition_26(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_26(id0); }

  private native void GetPosition_27(double id0[]);
  public void GetPosition(double id0[])
    { GetPosition_27(id0); }

  private native long GetProperty_28();
  public vtkProperty GetProperty() {
    long temp = GetProperty_28();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_29();
  public vtkProperty GetSelectedProperty() {
    long temp = GetSelectedProperty_29();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActiveProperty_30();
  public vtkProperty GetActiveProperty() {
    long temp = GetActiveProperty_30();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRenderer_31(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_31(id0); }

  private native void BuildRepresentation_32();
  public void BuildRepresentation()
    { BuildRepresentation_32(); }

  private native void StartWidgetInteraction_33(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_33(id0); }

  private native void WidgetInteraction_34(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_34(id0); }

  private native int ComputeInteractionState_35(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_35(id0,id1,id2); }

  private native void SetDisplayPosition_36(double id0[]);
  public void SetDisplayPosition(double id0[])
    { SetDisplayPosition_36(id0); }

  private native void GetActors_37(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_37(id0); }

  private native void ReleaseGraphicsResources_38(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_38(id0); }

  private native int RenderOverlay_39(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_39(id0); }

  private native int RenderOpaqueGeometry_40(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_40(id0); }

  private native int RenderTranslucentPolygonalGeometry_41(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_41(id0); }

  private native int HasTranslucentPolygonalGeometry_42();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_42(); }

  private native void ShallowCopy_43(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_43(id0); }

  private native void Highlight_44(int id0);
  public void Highlight(int id0)
    { Highlight_44(id0); }

  public vtkConstrainedPointHandleRepresentation() { super(); }

  public vtkConstrainedPointHandleRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
